@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
     pygments.lexers.markup
     ~~~~~~~~~~~~~~~~~~~~~~
@@ -503,7 +502,7 @@ class MarkdownLexer(RegexLexer):
     .. versionadded:: 2.2
     """
     name = 'markdown'
-    aliases = ['md']
+    aliases = ['md', 'markdown']
     filenames = ['*.md', '*.markdown']
     mimetypes = ["text/x-markdown"]
     flags = re.MULTILINE
